@@ -21,7 +21,7 @@ fi
 
 echo "checking button.."
 
-sleep "`cat /home/user/.config/savepress | grep "vdelay" | sed 's/vdelay: //g'`"
+sleep "`cat /home/user/.config/savepress | grep "vdelay" | sed 's/vdelay: //g' | sed 's/ //g'`"
 
 if [ `hal-get-property --udi /org/freedesktop/Hal/devices/platform_kb_lock --key button.state.value` == true ]; then {
 	echo "button pressed.."
@@ -51,7 +51,7 @@ if [ `hal-get-property --udi /org/freedesktop/Hal/devices/platform_kb_lock --key
 		# activate settings
 		echo "`/usr/sbin/kernel-config show | grep "max" | sed 's/. frequency//g'`" > /tmp/savepress-value
 		echo "`/usr/sbin/kernel-config show | grep "min" | sed 's/. frequency//g'`" >> /tmp/savepress-value
-		if [ "`cat /home/user/.config/savepress | grep "vwlan" | sed 's/vwlan: //g'`" == "true" ]; then {
+		if [ "`cat /home/user/.config/savepress | grep "vwlan" | sed 's/vwlan: //g' | sed 's/ //g'`" == "True" ]; then {
 			if [ "`/sbin/ifconfig wlan0 | grep "inet addr" | awk -F: '{print $2}' | awk '{print $1}'`" != "" ]; then {
 				dbus-send --system --dest=com.nokia.icd /com/nokia/icd_ui com.nokia.icd_ui.disconnect boolean:true
 				}
@@ -59,12 +59,12 @@ if [ `hal-get-property --udi /org/freedesktop/Hal/devices/platform_kb_lock --key
 			}
 		fi
 		
-		if [ "`cat /home/user/.config/savepress | grep "vblue" | sed 's/vblue: //g'`" == "true" ]; then {
+		if [ "`cat /home/user/.config/savepress | grep "vblue" | sed 's/vblue: //g' | sed 's/ //g'`" == "True" ]; then {
 			dbus-send --system --type=method_call --dest=org.bluez $(dbus-send --system --print-reply --dest=org.bluez / org.bluez.Manager.ListAdapters | awk -F "\"" '/at/ {print $2}') org.bluez.Adapter.SetProperty string:Powered variant:boolean:false
 			}
 		fi
 
-		if [ "`cat /home/user/.config/savepress | grep "voffline" | sed 's/voffline: //g'`" == "true" ]; then {
+		if [ "`cat /home/user/.config/savepress | grep "voffline" | sed 's/voffline: //g' | sed 's/ //g'`" == "True" ]; then {
 #			if [ "`dbus-send --print-reply --system --dest=com.nokia.mce --type=method_call /com/nokia/mce/request com.nokia.mce.request.get_device_mode | grep -q normal`" == "normal" ]; then {
 				dbus-send --system --dest=com.nokia.mce --type=method_call /com/nokia/mce/request com.nokia.mce.request.req_device_mode_change string:"offline"
 				echo "offline" >> /tmp/savepress-value
@@ -72,7 +72,7 @@ if [ `hal-get-property --udi /org/freedesktop/Hal/devices/platform_kb_lock --key
 #			fi
 			}
 		else {
-			if [ "`cat /home/user/.config/savepress | grep "v2g" | sed 's/v2g: //g'`" == "true" ]; then {
+			if [ "`cat /home/user/.config/savepress | grep "v2g" | sed 's/v2g: //g' | sed 's/ //g'`" == "True" ]; then {
 				netmode="`dbus-send --system --type=method_call --print-reply --dest=com.nokia.phone.net /com/nokia/phone/net Phone.Net.get_selected_radio_access_technology | awk '/b/ {print $2}'`"
 				if [ "$netmode" != "1" ]; then {
 					echo "mode: $netmode" >> /tmp/savepress-value
@@ -86,7 +86,7 @@ if [ `hal-get-property --udi /org/freedesktop/Hal/devices/platform_kb_lock --key
 		run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"savepress is activated!"
 		sleep 1
 		dbus-send --system --type=method_call --dest=com.nokia.mce /com/nokia/mce/request com.nokia.mce.request.req_tklock_mode_change string:"locked"
-		/usr/sbin/kernel-config limits `cat /home/user/.config/savepress | grep "vmin" | sed 's/vmin: //g'` `cat /home/user/.config/savepress | grep "vmax" | sed 's/vmax: //g'`
+		/usr/sbin/kernel-config limits `cat /home/user/.config/savepress | grep "vmin" | sed 's/vmin: //g' | sed 's/ //g'` `cat /home/user/.config/savepress | grep "vmax" | sed 's/vmax: //g' | sed 's/ //g'`
 		}
 	fi
 	echo "done.."
